#include "mimic.h"
#include "fsdata.h"


/**
 * local filesystem support.
 */
LocalFileSystem lf("local");

/**
 * MiMic RemoteMCU httpd.<br/>
 * <p>Service list</p>
 * <pre>
 * /rom/ - romfs
 * /setup/ - MiMic configulation REST API.
 * /local/ - mbed LocalFileSystem
 * /mvm/   - MiMicVM REST API
 * </pre>
 */

class MiMicRemoteMcu:public MiMic::Httpd
{
private:
    ModRomFiles modromfs; //ROM file module
    ModMiMicSetting mimicsetting; //mimic setting API
    ModRemoteMcu remotemcu; // remotemcu API
    ModLocalFileSystem modlocal; //basic URL parser
    
public:
    MiMicRemoteMcu():Httpd(80)
    {
        this->modromfs.setParam("rom",RMCU_FSDATA,19);
        this->mimicsetting.setParam("setup");
        this->remotemcu.setParam("mvm");
        this->modlocal.setParam("local");
    }
    virtual void onRequest(HttpdConnection& i_connection)
    {
        //try to ModRomFS module.
        if(this->modromfs.execute(i_connection)){
            return;
        }
        //try to ModMiMicSetting module.
        if(this->mimicsetting.execute(i_connection)){
            return;
        }
        //try to ModRemoteMcu module.
        if(this->remotemcu.execute(i_connection)){
            return;
        }
        //try to ModLocalFileSystem
        if(this->modlocal.execute(i_connection)){
            return;
        }
        
        //Otherwise, Send the redirect response to /rom/index.html
        i_connection.sendHeader(301,
            "text/html",
            "Status: 301:Moved Permanently\r\n"
            "Location: /rom/index.html\r\n");
        return;
    }
};

int main()
{
    NetConfig cfg; //create network configulation
    Net net(cfg);  //create a net instance.
    MiMicRemoteMcu httpd; //create a httpd instance.
    httpd.loop();  //start httpd loop.
    return 0;
}
